@@ -1,6 +1,6 @@
 package Puzzle::MasonHandler;
 
-our $VERSION = '0.13';
+our $VERSION = '0.21';
 
 use HTML::Mason::ApacheHandler();
 
@@ -18,24 +18,28 @@ use strict;
 
 my %perl2apache 	= (
 						args_method			=> 'MasonArgsMethod',
-              			comp_root			=> 'MasonCompRoot',
+						comp_root			=> 'MasonCompRoot',
 						data_dir			=> 'MasonDataDir',
 						code_cache_max_size	=> 'MasonCodeCacheMaxSize',
 						autoflush 			=> 'MasonAutoflush',
 						dhandler_name 		=> 'MasonDhandlerName',
 						request_class		=> 'MasonRequestClass',
+						error_mode			=> 'MasonErrorMode',
+						static_source		=> 'MasonStaticSource',
 );
 
 my %ah;
 
 sub params 		{return 	( 
 						args_method			=> 'mod_perl',
-              			comp_root			=> "/www/$_[0]/www",
-               			data_dir			=> "/var/cache/mason/cache/$_[0]",
+						comp_root			=> "/www/$_[0]/www",
+						data_dir			=> "/var/cache/mason/cache/$_[0]",
 						code_cache_max_size	=> 0,
 						autoflush 			=> 0,
 						dhandler_name 		=> 'dhandler.mpl',
 						request_class		=> 'Puzzle::Request',
+						error_mode			=> 'output',
+						static_source		=> 0,
 )};
 
 sub handler {
